@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0003';
+our $VERSION = '0.0004';
 
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
@@ -26,14 +26,12 @@ has net => (
     is      => 'ro',
     isa     => sub { die "$_[0] is not a hashref" unless ref $_[0] eq 'HASH' },
     default => sub {
-        {
-            1 => [qw(1 2 3 4 5 6)],
-            2 => [qw(3 5)],
-            3 => [qw(2 4 6)],
-            4 => [qw(1 2 3 5)],
-            5 => [qw(1)],
-            6 => [qw(2 4)],
-        };
+      { 1 => [qw( 1 2 3 4 5 6 )],
+        2 => [qw( 3 4 5 )],
+        3 => [qw( 1 2 4 6 )],
+        4 => [qw( 1 3 5 6 )],
+        5 => [qw( 1 4 6 )],
+        6 => [qw( 1 2 4 5 )] }
     },
 );
 
@@ -80,6 +78,13 @@ has resolve => (
 );
 
 
+has substitute => (
+    is      => 'ro',
+    isa     => sub { die "$_[0] is not a valid boolean" unless $_[0] =~ /^[01]$/ },
+    default => sub { 0 },
+);
+
+
 has flat => (
     is      => 'ro',
     isa     => sub { die "$_[0] is not a valid boolean" unless $_[0] =~ /^[01]$/ },
@@ -131,7 +136,15 @@ sub generate {
 
     my @scale = get_scale_notes($self->scale_note, $self->scale_name);
 
-    my @phrase = map { $scale[$_ - 1] . $self->chords->[$_ - 1] } @progression;
+    my $chords = $self->chords;
+
+    if ($self->substitute) {
+        for my $chord (@$chords) {
+            $chord = int rand 2 ? $self->substitution($chord) : $chord;
+        }
+    }
+
+    my @phrase = map { $scale[$_ - 1] . $chords->[$_ - 1] } @progression;
     print "Phrase: @phrase\n" if $self->verbose;
 
     # Add octaves to the chord notes
@@ -162,6 +175,40 @@ sub generate {
     return \@notes;
 }
 
+
+# These gymnastics are performed to appease Music::Chord::Note
+sub substitution {
+    my ($self, $chord) = @_;
+
+    my $substitute = $chord;
+
+    if (
+        $chord eq ''
+        || $chord eq 'm'
+        || $chord eq 'dim'
+        || $chord eq 'aug'
+    ) {
+        $substitute = $chord . 7;
+    }
+    elsif ($chord eq '-5' || $chord eq '-9') {
+        $substitute = "7($chord)";
+    }
+    elsif ($chord eq 'M7') {
+        my $roll = int rand 3;
+        $substitute = $roll == 0 ? 'M9' : $roll == 1 ? 'M11' : 'M13';
+    }
+    elsif ($chord eq '7') {
+        my $roll = int rand 3;
+        $substitute = $roll == 0 ? '9' : $roll == 1 ? '11' : '13';
+    }
+    elsif ($chord eq 'm7') {
+        my $roll = int rand 3;
+        $substitute = $roll == 0 ? 'm9' : $roll == 1 ? 'm11' : 'm13';
+    }
+
+    return $substitute;
+}
+
 1;
 
 __END__
@@ -176,7 +223,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0003
+version 0.0004
 
 =head1 SYNOPSIS
 
@@ -186,6 +233,8 @@ version 0.0003
 
   my $notes = $prog->generate;
 
+  my $chord = $prog->substitution('m'); # m7
+
 =head1 DESCRIPTION
 
 C<Music::Chord::Progression> creates network transition chord
@@ -205,6 +254,15 @@ The network transitions between chords of the progression.
 
 Default:
 
+  { 1 => [qw( 1 2 3 4 5 6 )],
+    2 => [qw( 3 4 5 )],
+    3 => [qw( 1 2 4 6 )],
+    4 => [qw( 1 3 5 6 )],
+    5 => [qw( 1 4 6 )],
+    6 => [qw( 1 2 4 5 )] }
+
+Alternative example:
+
   { 1 => [qw( 1 2 3 4 5 6 )],
     2 => [qw( 3 5 )],
     3 => [qw( 2 4 6 )],
@@ -221,6 +279,10 @@ number of keys in the B<net>.
 
 Default: C<[ '', 'm', 'm', '', '', 'm' ]>
 
+Alternative example:
+
+  [ 'M7', 'm7', 'm7', 'M7', '7', 'm7' ]
+
 =head2 scale_name
 
 The name of the scale.
@@ -251,6 +313,12 @@ Whether to end the progression with the tonic chord or not.
 
 Default: C<1>
 
+=head2 substitute
+
+Whether to perform jazz chord substitution.
+
+Default: C<0>
+
 =head2 flat
 
 Whether to use flats instead of sharps in the chords or not.
@@ -286,6 +354,18 @@ Create a new C<Music::Chord::Progression> object.
 
 Generate a new chord progression.
 
+=head2 substitution
+
+Perform a jazz substitution on the given B<chord>.
+
+Rules:
+
+  * Any chord can be changed to a dominant
+
+  * Any dominant chord can be changed to a 9, 11, or 13
+
+  * Any chord can be changed to a chord a tritone away (not implemented)
+
 =head1 SEE ALSO
 
 L<Data::Dumper::Compact>
